@@ -15,12 +15,13 @@ from pkg_resources import resource_filename
 from bs4 import BeautifulSoup
 
 from astropy.extern.six.moves.urllib_parse import urljoin, urlparse
-from astropy.extern.six import iteritems
+from astropy.extern.six import iteritems, StringIO
 from astropy.extern import six
 from astropy.table import Table, Column
 from astropy import log
 from astropy.utils.console import ProgressBar
 from astropy import units as u
+import astropy.coordinates as coord
 import astropy.io.votable as votable
 
 from ..exceptions import (RemoteServiceError, TableParseError,
@@ -95,7 +96,7 @@ class AlmaClass(QueryWithLogin):
         """
         coordinate = commons.parse_coordinates(coordinate)
         cstr = coordinate.fk5.to_string(style='hmsdms', sep=':')
-        rdc = "{cstr}, {rad}".format(cstr=cstr, rad=radius.to(u.deg).value)
+        rdc = "{cstr}, {rad}".format(cstr=cstr, rad=coord.Angle(radius).deg)
 
         if payload is None:
             payload = {}
@@ -105,7 +106,8 @@ class AlmaClass(QueryWithLogin):
                                 science=science, **kwargs)
 
     def query_async(self, payload, cache=True, public=True, science=True,
-                    view_format='raw', get_query_payload=False, **kwargs):
+                    max_retries=5,
+                    get_html_version=False, get_query_payload=False, **kwargs):
         """
         Perform a generic query with user-specified payload
 
@@ -117,17 +119,24 @@ class AlmaClass(QueryWithLogin):
             http://almascience.org/aq or using the `help` method
         cache : bool
             Cache the query?
+            (note: HTML queries *cannot* be cached using the standard caching
+            mechanism because the URLs are different each time
         public : bool
             Return only publicly available datasets?
         science : bool
             Return only data marked as "science" in the archive?
+
         """
 
         url = urljoin(self._get_dataarchive_url(), 'aq/')
 
         payload.update(kwargs)
-        payload.update({'result_view': view_format, 'format': 'VOTABLE',
-                        'download': 'true'})
+        if get_html_version:
+            payload.update({'result_view': 'observation', 'format': 'URL',
+                            'download': 'true'})
+        else:
+            payload.update({'result_view': 'raw', 'format': 'VOTABLE',
+                            'download': 'true'})
         if public:
             payload['public_data'] = 'public'
         if science:
@@ -139,11 +148,49 @@ class AlmaClass(QueryWithLogin):
             return payload
 
         response = self._request('GET', url, params=payload,
-                                 timeout=self.TIMEOUT, cache=cache)
+                                 timeout=self.TIMEOUT,
+                                 cache=cache and not get_html_version)
         self._last_response = response
         response.raise_for_status()
 
-        return response
+        if get_html_version:
+            if 'run' not in response.text:
+                if max_retries > 0:
+                    log.info("Failed query.  Retrying up to {0} more times"
+                             .format(max_retries))
+                    return self.query_async(payload=payload, cache=False,
+                                            public=public, science=science,
+                                            max_retries=max_retries-1,
+                                            get_html_version=get_html_version,
+                                            get_query_payload=get_query_payload,
+                                            **kwargs)
+                raise RemoteServiceError("Incorrect return from HTML table query.")
+            response2 = self._request('GET',
+                                      "{0}/{1}/{2}".format(
+                                          self._get_dataarchive_url(), 'aq',
+                                          response.text),
+                                      params={'query_url':
+                                              response.url.split("?")[-1]},
+                                      timeout=self.TIMEOUT,
+                                      cache=False,
+                                      )
+            self._last_response = response2
+            response2.raise_for_status()
+            if len(response2.text) == 0:
+                if max_retries > 0:
+                    log.info("Failed (empty) query.  Retrying up to {0} more times"
+                             .format(max_retries))
+                    return self.query_async(payload=payload, cache=cache,
+                                            public=public, science=science,
+                                            max_retries=max_retries-1,
+                                            get_html_version=get_html_version,
+                                            get_query_payload=get_query_payload,
+                                            **kwargs)
+                raise RemoteServiceError("Empty return.")
+            return response2
+
+        else:
+            return response
 
     def validate_query(self, payload, cache=True):
         """
@@ -177,11 +224,13 @@ class AlmaClass(QueryWithLogin):
         access for querying data
         """
         if not hasattr(self, 'dataarchive_url'):
-            if self.archive_url == 'http://almascience.org':
-                response = self._request(
-                    'GET', self.archive_url + "/aq", cache=False)
+            if self.archive_url in ('http://almascience.org', 'https://almascience.org'):
+                response = self._request('GET', self.archive_url + "/aq",
+                                         cache=False)
                 response.raise_for_status()
-                self.dataarchive_url = response.url.replace("/aq/", "")
+                # Jan 2017: we have to force https because the archive doesn't
+                # tell us it needs https.
+                self.dataarchive_url = response.url.replace("/aq/", "").replace("http://", "https://")
             else:
                 self.dataarchive_url = self.archive_url
         return self.dataarchive_url
@@ -238,8 +287,11 @@ class AlmaClass(QueryWithLogin):
                                  timeout=self.TIMEOUT, cache=False)
         self._staging_log['initial_response'] = response
         log.debug("First response URL: {0}".format(response.url))
+        if 'login' in response.url:
+            raise ValueError("You must login before downloading this data set.")
+
         if response.status_code == 405:
-            if hasattr(self,'_last_successful_staging_log'):
+            if hasattr(self, '_last_successful_staging_log'):
                 log.warning("Error 405 received.  If you have previously staged "
                             "the same UIDs, the result returned is probably "
                             "correct, otherwise you may need to create a fresh "
@@ -349,7 +401,7 @@ class AlmaClass(QueryWithLogin):
 
         return data_sizes, totalsize.to(u.GB)
 
-    def download_files(self, files, cache=True):
+    def download_files(self, files, savedir=None, cache=True, continuation=True):
         """
         Given a list of file URLs, download them
 
@@ -357,9 +409,13 @@ class AlmaClass(QueryWithLogin):
         once, so the return may have a different length than the input list
         """
         downloaded_files = []
+        if savedir is None:
+            savedir = self.cache_location
         for fileLink in unique(files):
             filename = self._request("GET", fileLink, save=True,
-                                     timeout=self.TIMEOUT, cache=cache)
+                                     savedir=savedir,
+                                     timeout=self.TIMEOUT, cache=cache,
+                                     continuation=continuation)
             downloaded_files.append(filename)
         return downloaded_files
 
@@ -403,20 +459,36 @@ class AlmaClass(QueryWithLogin):
         if not verbose:
             commons.suppress_vo_warnings()
 
-        fixed_content = self._hack_band_vofix(response.content)
-        tf = six.BytesIO(fixed_content)
-        vo_tree = votable.parse(tf, pedantic=False, invalid='mask')
-        first_table = vo_tree.get_first_table()
-        table = first_table.to_table(use_names_over_ids=True)
+        if 'run?' in response.url:
+            if response.text == "":
+                raise RemoteServiceError("Empty return.")
+            # this is a CSV-like table returned via a direct browser request
+            import pandas
+            table = Table.from_pandas(pandas.read_csv(StringIO(response.text)))
+
+        else:
+            fixed_content = self._hack_bad_arraysize_vofix(response.content)
+            tf = six.BytesIO(fixed_content)
+            vo_tree = votable.parse(tf, pedantic=False, invalid='mask')
+            first_table = vo_tree.get_first_table()
+            table = first_table.to_table(use_names_over_ids=True)
+
         return table
 
-    def _hack_band_vofix(self, text):
+    def _hack_bad_arraysize_vofix(self, text):
         """
-        Hack to fix an error in the ALMA votables present in most 2016 queries.
+        Hack to fix an error in the ALMA votables present in most 2016 and 2017 queries.
 
         The problem is that this entry:
         '      <FIELD name="Band" datatype="char" ID="32817" xtype="adql:VARCHAR" arraysize="0*">\r',
-        has an invalid ``arraysize`` entry.
+        has an invalid ``arraysize`` entry.  Also, it returns a char, but it
+        should be an int.
+
+        Since that problem was discovered and fixed, many other entries have
+        the same error.
+
+        According to the IVOA, the tables are wrong, not astropy.io.votable:
+        http://www.ivoa.net/documents/VOTable/20130315/PR-VOTable-1.3-20130315.html#ToC11
         """
         lines = text.split(b"\n")
         newlines = []
@@ -424,11 +496,13 @@ class AlmaClass(QueryWithLogin):
         for ln in lines:
             if b'FIELD name="Band"' in ln:
                 ln = ln.replace(b'arraysize="0*"', b'arraysize="1*"')
+                ln = ln.replace(b'datatype="char"', b'datatype="int"')
+            elif b'arraysize="0*"' in ln:
+                ln = ln.replace(b'arraysize="0*"', b'arraysize="*"')
             newlines.append(ln)
 
         return b"\n".join(newlines)
 
-
     def _login(self, username=None, store_password=False,
                reenter_password=False):
         """
@@ -549,7 +623,7 @@ class AlmaClass(QueryWithLogin):
             columns = [Column(data=data[0], name='ID'),
                        Column(data=data[1], name='Files')]
             tbl = Table(columns)
-            assert len(tbl) == response.text.count('<tr') == 8497
+            assert len(tbl) == 8497
             self._cycle0_tarfile_content_table = tbl
         else:
             tbl = self._cycle0_tarfile_content_table
@@ -572,7 +646,7 @@ class AlmaClass(QueryWithLogin):
             self._cycle0_table.rename_column('col2', 'uid')
         return self._cycle0_table
 
-    def get_files_from_tarballs(self, downloaded_files, regex='.*\.fits$',
+    def get_files_from_tarballs(self, downloaded_files, regex=r'.*\.fits$',
                                 path='cache_path', verbose=True):
         """
         Given a list of successfully downloaded tarballs, extract files
@@ -619,7 +693,7 @@ class AlmaClass(QueryWithLogin):
 
         return filelist
 
-    def download_and_extract_files(self, urls, delete=True, regex='.*\.fits$',
+    def download_and_extract_files(self, urls, delete=True, regex=r'.*\.fits$',
                                    include_asdm=False, path='cache_path',
                                    verbose=True):
         """
@@ -732,7 +806,7 @@ class AlmaClass(QueryWithLogin):
             root = BeautifulSoup(querypage.content, "html5lib")
             sections = root.findAll('td', class_='category')
 
-            whitespace = re.compile("\s+")
+            whitespace = re.compile(r"\s+")
 
             help_list = []
             for section in sections:
@@ -799,6 +873,9 @@ class AlmaClass(QueryWithLogin):
             self._valid_params = [row[1]
                                   for title, section in help_list
                                   for row in section]
+            if len(self._valid_params) == 0:
+                raise ValueError("The query validation failed for unknown "
+                                 "reasons.  Try again?")
             # These parameters are entirely hidden, but Felix says they are
             # allowed
             self._valid_params.append('download')
@@ -847,7 +924,7 @@ class AlmaClass(QueryWithLogin):
 
             if len(tds) > 3 and (cl and tr['class'][0] == 'fileRow'):
                 # New Style
-                size, unit = re.search('(-|[0-9\.]*)([A-Za-z]*)',
+                size, unit = re.search(r'(-|[0-9\.]*)([A-Za-z]*)',
                                        tds[2].text).groups()
                 href = tds[1].find('a')
                 if size == '':
@@ -877,7 +954,7 @@ class AlmaClass(QueryWithLogin):
             elif len(tds) > 3 and tds[2].find('a'):
                 # Old Style
                 href = tds[2].find('a')
-                size, unit = re.search('([0-9\.]*)([A-Za-z]*)',
+                size, unit = re.search(r'([0-9\.]*)([A-Za-z]*)',
                                        tds[3].text).groups()
                 columns['uid'].append(uid)
                 columns['URL'].append(href.attrs['href'])
@@ -944,6 +1021,7 @@ class AlmaClass(QueryWithLogin):
         tbl = Table([Column(name=k, data=v) for k, v in iteritems(columns)])
         return tbl
 
+
 Alma = AlmaClass()
 
 
