@@ -3,8 +3,9 @@ import tempfile
 import shutil
 import numpy as np
 import os
-import requests
-from astropy.tests.helper import pytest, remote_data
+import pytest
+
+from astropy.tests.helper import remote_data
 from astropy import coordinates
 from astropy import units as u
 from astropy.extern.six.moves.urllib_parse import urlparse
@@ -30,7 +31,7 @@ class TestAlma:
         # Alma.archive_url = "https://2016-03.asa-test.alma.cl/aq/"
         # starting somewhere between Nov 2015 and Jan 2016, the beta server
         # stopped serving the actual data, making all staging attempts break
-        #Alma.archive_url = 'http://beta.cadc-ccda.hia-iha.nrc-cnrc.gc.ca'
+        # Alma.archive_url = 'http://beta.cadc-ccda.hia-iha.nrc-cnrc.gc.ca'
 
     @pytest.fixture()
     def temp_dir(self, request):
@@ -53,11 +54,15 @@ class TestAlma:
         alma.cache_location = temp_dir
 
         result_s = alma.query_object('Sgr A*')
-        assert b'2011.0.00217.S' in result_s['Project code']
+        # cycle 1 data are missing from the archive assert b'2011.0.00887.S' in result_s['Project code']
+        assert b'2013.1.00857.S' in result_s['Project code']
         c = coordinates.SkyCoord(266.41681662 * u.deg, -29.00782497 * u.deg,
                                  frame='fk5')
         result_c = alma.query_region(c, 1 * u.deg)
-        assert b'2011.0.00217.S' in result_c['Project code']
+        assert b'2013.1.00857.S' in result_c['Project code']
+        # "The Brick", g0.253, is in this one
+        # assert b'2011.0.00217.S' in result_c['Project code'] # missing cycle 1 data
+        assert b'2012.1.00932.S' in result_c['Project code']
 
     def test_m83(self, temp_dir, recwarn):
         alma = Alma()
@@ -73,16 +78,16 @@ class TestAlma:
 
         # test re-staging
         # (has been replaced with warning)
-        #with pytest.raises(requests.HTTPError) as ex:
+        # with pytest.raises(requests.HTTPError) as ex:
         #    link_list = alma.stage_data(uids)
-        #assert ex.value.args[0] == ('Received an error 405: this may indicate you have '
+        # assert ex.value.args[0] == ('Received an error 405: this may indicate you have '
         #                            'already staged the data.  Try downloading the '
         #                            'file URLs directly with download_files.')
 
         # log.warning doesn't actually make a warning
-        #link_list = alma.stage_data(uids)
-        #w = recwarn.pop()
-        #assert (str(w.message) == ('Error 405 received.  If you have previously staged the '
+        # link_list = alma.stage_data(uids)
+        # w = recwarn.pop()
+        # assert (str(w.message) == ('Error 405 received.  If you have previously staged the '
         #                           'same UIDs, the result returned is probably correct,'
         #                           ' otherwise you may need to create a fresh astroquery.Alma instance.'))
 
@@ -91,36 +96,33 @@ class TestAlma:
         alma.cache_location = temp_dir
 
         result_s = alma.query_object('Sgr A*')
-        assert b'2011.0.00217.S' in result_s['Project code']
-        # UID comes from:
-        # 2011.0.00217.S  G0.25+0.02 266.53995833333346 -28.709500000000009      3 1.4544413048949709             976.5625    2280.739   2013-09-07 [86.26..88.14GHz,976.56kHz,null] U [88.15..90.03GHz,976.56kHz,null] U [98.19..100.07GHz,976.56kHz,null] U [100.15..102.03GHz,976.56kHz,null]  3110.9112850878114        XX YY 2012-07-29 02:01:54 Rathborne, Jill 1.7593164              uid://A002/X391d0b/X7b uid://A002/X47aefc/X369 Globular cluster formation: caught in the act            S      TARGET    365.55225721174787          Y     7
-        # (this information is included in comments because the ALMA archive
-        # has apparently changed UIDs, but the associated data should never go
-        # missing)
-        assert b'uid://A002/X47aefc/X369' in result_s['Asdm uid']
-        match = result_s['Asdm uid'] == b'uid://A002/X47aefc/X369'
+        # assert b'2011.0.00887.S' in result_s['Project code']
+        assert b'2013.1.00857.S' in result_s['Project code']
+        # assert b'uid://A002/X40d164/X1b3' in result_s['Asdm uid']
+        assert b'uid://A002/X651f57/Xade' in result_s['Asdm uid']
+        # match = result_s['Asdm uid'] == b'uid://A002/X40d164/X1b3'
+        match = result_s['Asdm uid'] == b'uid://A002/X651f57/Xade'
         uid = result_s['Asdm uid'][match]
 
         result = alma.stage_data(uid)
 
-        assert ('uid___A002_X47aefc' in
+        assert ('uid___A002_X651f57_Xade' in
                 os.path.split(result['URL'][0])[1])
 
         # test re-staging
-        #with pytest.raises(requests.HTTPError) as ex:
+        # with pytest.raises(requests.HTTPError) as ex:
         #    result = alma.stage_data([uid])
-        #assert ex.value.args[0] == ('Received an error 405: this may indicate you have '
+        # assert ex.value.args[0] == ('Received an error 405: this may indicate you have '
         #                            'already staged the data.  Try downloading the '
         #                            'file URLs directly with download_files.')
 
         # log.warning doesn't actually make a warning
-        #result = alma.stage_data([uid])
-        #w = recwarn.pop()
-        #assert (str(w.message) == ('Error 405 received.  If you have previously staged the '
+        # result = alma.stage_data([uid])
+        # w = recwarn.pop()
+        # assert (str(w.message) == ('Error 405 received.  If you have previously staged the '
         #                           'same UIDs, the result returned is probably correct,'
         #                           ' otherwise you may need to create a fresh astroquery.Alma instance.'))
 
-
     def test_doc_example(self, temp_dir):
         alma = Alma()
         alma.cache_location = temp_dir
@@ -128,19 +130,20 @@ class TestAlma:
         alma2.cache_location = temp_dir
         m83_data = alma.query_object('M83')
         # the order can apparently sometimes change
-        assert set(m83_data.colnames) == set(all_colnames)
+        # These column names change too often to keep testing.
+        # assert set(m83_data.colnames) == set(all_colnames)
         galactic_center = coordinates.SkyCoord(0 * u.deg, 0 * u.deg,
                                                frame='galactic')
         gc_data = alma.query_region(galactic_center, 1 * u.deg)
-        #assert len(gc_data) >= 425 # Feb 8, 2016
-        assert len(gc_data) >= 50 # Nov 16, 2016
+        # assert len(gc_data) >= 425 # Feb 8, 2016
+        assert len(gc_data) >= 50  # Nov 16, 2016
 
         uids = np.unique(m83_data['Asdm uid'])
         assert b'uid://A002/X3b3400/X90f' in uids
         X90f = (m83_data['Asdm uid'] == b'uid://A002/X3b3400/X90f')
-        assert X90f.sum() == 1 # Nov 16, 2016: reduced from 45
+        assert X90f.sum() == 2  # Jul 2, 2017: increased from 1
         X31 = (m83_data['Member ous id'] == b'uid://A002/X3216af/X31')
-        assert X31.sum() == 1 # Nov 16, 2016: reduced from 225
+        assert X31.sum() == 2  # Jul 2, 2017: increased from 1
 
         asdm = alma.stage_data('uid://A002/X3b3400/X90f')
         totalsize_asdm = asdm['size'].sum() * u.Unit(asdm['size'].unit)
@@ -160,8 +163,13 @@ class TestAlma:
         result = alma.query(payload={'start_date': '<11-11-2011'},
                             public=False, science=True)
         # Nov 16, 2016: 159
-        assert len(result) == 159
+        # Apr 25, 2017: 150
+        # Jul 2, 2017: 160
+        assert len(result) == 160
 
+    # As of April 2017, these data are *MISSING FROM THE ARCHIVE*.
+    # This has been reported, as it is definitely a bug.
+    @pytest.mark.xfail
     @pytest.mark.bigdata
     def test_cycle1(self, temp_dir):
         # About 500 MB
@@ -186,7 +194,7 @@ class TestAlma:
         # A 2-row table may not be OK any more, but that's what it used to
         # be...
         assert len(uid_url_table_asdm) == 1
-        assert len(uid_url_table_mous) >= 2 # now is len=3 (Nov 17, 2016)
+        assert len(uid_url_table_mous) >= 2  # now is len=3 (Nov 17, 2016)
 
         # URL should look like:
         # https://almascience.eso.org/dataPortal/requests/anonymous/944120962/ALMA/2012.1.00912.S_uid___A002_X5a9a13_X528_001_of_001.tar/2012.1.00912.S_uid___A002_X5a9a13_X528_001_of_001.tar
@@ -197,7 +205,7 @@ class TestAlma:
         urls_to_download = uid_url_table_mous[small]['URL']
 
         uri = urlparse(urls_to_download[0])
-        assert uri.path == ('/dataPortal/requests/anonymous/{0}/ALMA/2012.1.00912.S_uid___A002_X5a9a13_X528_001_of_001.tar/2012.1.00912.S_uid___A002_X5a9a13_X528_001_of_001.tar'
+        assert uri.path == ('/dataPortal/requests/anonymous/{0}/ALMA/2012.1.00912.S_uid___A002_X5a9a13_X528_001_of_001.tar/2012.1.00912.S_uid___A002_X5a9a13_X528_001_of_001.tar'  # noqa
                             .format(a1._staging_log['staging_page_id']))
 
         # THIS IS FAIL
