@@ -1,3 +1,5 @@
+# Licensed under a 3-clause BSD style license - see LICENSE.rst
+
 from astropy.extern.six.moves.urllib import parse as urlparse
 from astropy.extern.six.moves import map, zip
 from astropy.extern.six import StringIO
@@ -11,13 +13,10 @@ from astropy import units as u
 from bs4 import BeautifulSoup
 
 from ..query import BaseQuery
-from ..utils import commons
-from ..utils import prepend_docstr_noreturns
-from ..utils import async_to_sync
+from ..utils import prepend_docstr_nosections, async_to_sync
 from . import conf
 from .utils import is_valid_transitions_param
 
-
 __all__ = ['AtomicLineList', 'AtomicLineListClass']
 
 
@@ -27,7 +26,7 @@ class AtomicLineListClass(BaseQuery):
     TIMEOUT = conf.timeout
 
     def __init__(self):
-        BaseQuery.__init__(self)
+        super(AtomicLineListClass, self).__init__()
         self._default_form_values = None
 
     def query_object(self, wavelength_range=None, wavelength_type=None,
@@ -37,7 +36,10 @@ class AtomicLineListClass(BaseQuery):
                      upper_level_energy_range=None, nmax=None,
                      multiplet=None, transitions=None,
                      show_fine_structure=None,
-                     show_auto_ionizing_transitions=None):
+                     show_auto_ionizing_transitions=None,
+                     output_columns=('spec', 'type', 'conf',
+                                     'term', 'angm', 'prob',
+                                     'ener')):
         """
         Queries Atomic Line List for the given parameters adnd returns the
         result as a `~astropy.table.Table`. All parameters are optional.
@@ -134,6 +136,14 @@ class AtomicLineListClass(BaseQuery):
             the ground state of the next ion are considered auto-ionizing
             levels.
 
+        output_columns : tuple
+            A Tuple of strings indicating which output columns are retrieved.
+            A subset of ('spec', 'type', 'conf', 'term', 'angm', 'prob',
+            'ener') should be used. Where each string corresponds to the
+            column titled Spectrum, Transition type, Configuration, Term,
+            Angular momentum, Transition probability and Level energies
+            respectively.
+
         Returns
         -------
         result : `~astropy.table.Table`
@@ -150,11 +160,12 @@ class AtomicLineListClass(BaseQuery):
             upper_level_energy_range=upper_level_energy_range, nmax=nmax,
             multiplet=multiplet, transitions=transitions,
             show_fine_structure=show_fine_structure,
-            show_auto_ionizing_transitions=show_auto_ionizing_transitions)
+            show_auto_ionizing_transitions=show_auto_ionizing_transitions,
+            output_columns=output_columns)
         table = self._parse_result(response)
         return table
 
-    @prepend_docstr_noreturns(query_object.__doc__)
+    @prepend_docstr_nosections(query_object.__doc__)
     def query_object_async(self, wavelength_range=None, wavelength_type='',
                            wavelength_accuracy=None, element_spectrum=None,
                            minimal_abundance=None, depl_factor=None,
@@ -162,7 +173,10 @@ class AtomicLineListClass(BaseQuery):
                            upper_level_energy_range=None, nmax=None,
                            multiplet=None, transitions=None,
                            show_fine_structure=None,
-                           show_auto_ionizing_transitions=None):
+                           show_auto_ionizing_transitions=None,
+                           output_columns=('spec', 'type', 'conf',
+                                           'term', 'angm', 'prob',
+                                           'ener')):
         """
         Returns
         -------
@@ -170,8 +184,8 @@ class AtomicLineListClass(BaseQuery):
             The HTTP response returned from the service.
         """
         if self._default_form_values is None:
-            response = commons.send_request(
-                self.FORM_URL, {}, self.TIMEOUT, 'GET')
+            response = self._request("GET", url=self.FORM_URL, data={},
+                                     timeout=self.TIMEOUT)
             bs = BeautifulSoup(response.text)
             form = bs.find('form')
             self._default_form_values = self._get_default_form_values(form)
@@ -229,7 +243,9 @@ class AtomicLineListClass(BaseQuery):
             'type': _type,
             'type2': type2,
             'hydr': show_fine_structure,
-            'auto': show_auto_ionizing_transitions}
+            'auto': show_auto_ionizing_transitions,
+            'form': output_columns,
+            'tptype': 'as_a'}
         response = self._submit_form(input)
         return response
 
@@ -255,6 +271,9 @@ class AtomicLineListClass(BaseQuery):
                 value = line[start:end].strip()
                 if value:
                     row.append(value)
+                else:
+                    # maintain table dimensions when data missing
+                    row.append('None')
             if row:
                 input.append('\t'.join(row))
         if input:
@@ -272,7 +291,8 @@ class AtomicLineListClass(BaseQuery):
         """
         if input is None:
             input = {}
-        response = commons.send_request(self.FORM_URL, {}, self.TIMEOUT, 'GET')
+        response = self._request("GET", url=self.FORM_URL, data={},
+                                 timeout=self.TIMEOUT)
         bs = BeautifulSoup(response.text)
         form = bs.find('form')
         # cache the default values to save HTTP traffic
@@ -285,7 +305,8 @@ class AtomicLineListClass(BaseQuery):
             if v is not None:
                 payload[k] = v
         url = urlparse.urljoin(self.FORM_URL, form.get('action'))
-        response = commons.send_request(url, payload, self.TIMEOUT)
+        response = self._request("POST", url=url, data=payload,
+                                 timeout=self.TIMEOUT)
         return response
 
     def _get_default_form_values(self, form):
@@ -317,6 +338,7 @@ class AtomicLineListClass(BaseQuery):
                         value = option.get('value', option.text.strip())
             if value and value not in [None, u'None', u'null']:
                 res[key].append(value)
+
         # avoid values with size 1 lists
         d = dict(res)
         for k, v in six.iteritems(d):
