@@ -22,14 +22,17 @@ try:
     PYTEST_HEADER_MODULES['pyregion'] = 'pyregion'
     del PYTEST_HEADER_MODULES['h5py']
     del PYTEST_HEADER_MODULES['Scipy']
-    del PYTEST_HEADER_MODULES['Pandas']
 except (NameError, KeyError):
     pass
 
 # Uncomment the following line to treat all DeprecationWarnings as
 # exceptions
-enable_deprecations_as_exceptions()
-
+#
+# The workaround can be removed once pyopenssl 1.7.20+ is out.
+import astropy
+if int(astropy.__version__[0]) > 1:
+    # The warnings_to_ignore_by_pyver parameter was added in astropy 2.0
+    enable_deprecations_as_exceptions(modules_to_ignore_on_import=['requests'])
 
 # This is to figure out the affiliated package version, rather than
 # using Astropy's
