@@ -2,6 +2,7 @@
 """Download of Fermi LAT (Large Area Telescope) data"""
 from __future__ import print_function
 import re
+import requests
 import time
 import astropy.units as u
 from ..query import BaseQuery
@@ -12,6 +13,7 @@ __all__ = ['FermiLAT', 'FermiLATClass',
            'GetFermilatDatafile', 'get_fermilat_datafile',
            ]
 
+
 @async_to_sync
 class FermiLATClass(BaseQuery):
     """
@@ -19,7 +21,8 @@ class FermiLATClass(BaseQuery):
     """
 
     request_url = conf.url
-    result_url_re = re.compile('The results of your query may be found at <a href="(http://fermi.gsfc.nasa.gov/.*?)"')
+    result_url_re = re.compile('The results of your query may be found at '
+                               '<a href="(http://fermi.gsfc.nasa.gov/.*?)"')
     TIMEOUT = conf.timeout
 
     def query_object_async(self, *args, **kwargs):
@@ -28,7 +31,9 @@ class FermiLATClass(BaseQuery):
 
         Returns
         -------
-        url : The URL of the page with the results (still need to scrape this page to download the data: easy for wget)
+        url : str
+            The URL of the page with the results (still need to scrape this
+            page to download the data: easy for wget)
         """
 
         payload = self._parse_args(*args, **kwargs)
@@ -36,21 +41,21 @@ class FermiLATClass(BaseQuery):
         if kwargs.get('get_query_payload'):
             return payload
 
-        result = commons.send_request(self.request_url,
-                                      payload,
-                                      self.TIMEOUT)
-
+        result = self._request("POST", url=self.request_url,
+                               data=payload, timeout=self.TIMEOUT)
         re_result = self.result_url_re.findall(result.text)
 
         if len(re_result) == 0:
-            raise ValueError("Results did not contain a result url... something went awry (that hasn't been tested yet)")
+            raise ValueError("Results did not contain a result url. something "
+                             "went awry (that hasn't been tested yet)")
         else:
             result_url = re_result[0]
 
         return result_url
 
-    def _parse_args(self, name_or_coords, searchradius='', obsdates='', timesys='Gregorian',
-                    energyrange_MeV='', LATdatatype='Photon', spacecraftdata=True):
+    def _parse_args(self, name_or_coords, searchradius='', obsdates='',
+                    timesys='Gregorian', energyrange_MeV='',
+                    LATdatatype='Photon', spacecraftdata=True):
         """
         Parameters
         ----------
@@ -74,16 +79,15 @@ class FermiLATClass(BaseQuery):
         payload_dict : Requests payload in a dictionary
         """
 
-
-        payload = {'shapefield':str(searchradius),
-                   'coordsystem':'J2000',
-                   'coordfield':_parse_coordinates(name_or_coords),
-                   'destination':'query',
-                   'timefield':obsdates,
+        payload = {'shapefield': str(searchradius),
+                   'coordsystem': 'J2000',
+                   'coordfield': _parse_coordinates(name_or_coords),
+                   'destination': 'query',
+                   'timefield': obsdates,
                    'timetype': timesys,
-                   'energyfield':energyrange_MeV,
+                   'energyfield': energyrange_MeV,
                    'photonOrExtendedOrNone': LATdatatype,
-                   'spacecraft':'on' if spacecraftdata else 'off'}
+                   'spacecraft': 'on' if spacecraftdata else 'off'}
 
         return payload
 
@@ -93,8 +97,10 @@ class FermiLATClass(BaseQuery):
         """
         return get_fermilat_datafile(result)
 
+
 FermiLAT = FermiLATClass()
 
+
 def _parse_coordinates(coordinates):
     try:
         c = commons.parse_coordinates(coordinates)
@@ -104,10 +110,12 @@ def _parse_coordinates(coordinates):
     except (u.UnitsError, TypeError):
         raise Exception("Coordinates not specified correctly")
 
+
 def _fermi_format_coords(c):
     c = c.transform_to('fk5')
     return "{0:0.5f},{1:0.5f}".format(c.ra.degree, c.dec.degree)
 
+
 class GetFermilatDatafile(object):
     """
     TODO: document
@@ -143,9 +151,9 @@ class GetFermilatDatafile(object):
         return fitsfile_urls
 
     def _check_page(self):
-        result_page = commons.send_request(self.result_url,
-                                           None,
-                                           self.TIMEOUT)
+        result_page = requests.post(url=self.result_url,
+                                    data=None,
+                                    timeout=self.TIMEOUT)
 
         pagedata = result_page.text
 
@@ -156,4 +164,5 @@ class GetFermilatDatafile(object):
         else:
             return fitsfile_urls
 
+
 get_fermilat_datafile = GetFermilatDatafile()
