@@ -2,7 +2,7 @@
 from __future__ import print_function
 import os
 import requests
-from astropy.tests.helper import pytest
+import pytest
 import astropy.coordinates as coord
 from ...utils.testing_tools import MockResponse
 from ... import fermi
@@ -21,12 +21,16 @@ def data_path(filename):
 
 @pytest.fixture
 def patch_post(request):
-    mp = request.getfuncargvalue("monkeypatch")
+    try:
+        mp = request.getfixturevalue("monkeypatch")
+    except AttributeError:  # pytest < 3
+        mp = request.getfuncargvalue("monkeypatch")
+    mp.setattr(fermi.FermiLAT, '_request', post_mockreturn)
     mp.setattr(requests, 'post', post_mockreturn)
     return mp
 
 
-def post_mockreturn(url, data=None, timeout=50, **kwargs):
+def post_mockreturn(method="POST", url=None, data=None, timeout=50, **kwargs):
     if data is not None:
         with open(data_path(DATA_FILES['async']), 'rb') as r:
             response = MockResponse(r.read(), **kwargs)
@@ -35,6 +39,7 @@ def post_mockreturn(url, data=None, timeout=50, **kwargs):
             response = MockResponse(r.read(), **kwargs)
     return response
 
+
 FK5_COORDINATES = coord.SkyCoord(10.68471, 41.26875, unit=('deg', 'deg'))
 
 # disable waiting so tests run fast
@@ -70,5 +75,6 @@ def test_FermiLAT_DelayedQuery():
     # TODO
     # print query
 
+
 if __name__ == '__main__':
     test_FermiLAT_query()
