@@ -5,11 +5,11 @@ IRSA
 
 API from
 
- http://irsa.ipac.caltech.edu/applications/Gator/GatorAid/irsa/catsearch.html
+ https://irsa.ipac.caltech.edu/applications/Gator/GatorAid/irsa/catsearch.html
 
 The URL of the IRSA catalog query service, CatQuery, is
 
- http://irsa.ipac.caltech.edu/cgi-bin/Gator/nph-query
+ https://irsa.ipac.caltech.edu/cgi-bin/Gator/nph-query
 
 The service accepts the following keywords, which are analogous to the search
 fields on the Gator search form:
@@ -127,11 +127,12 @@ class IrsaClass(BaseQuery):
             performing a cone or box search. The string can give coordinates
             in various coordinate systems, or the name of a source that will
             be resolved on the server (see `here
-            <http://irsa.ipac.caltech.edu/search_help.html>`_ for more
+            <https://irsa.ipac.caltech.edu/search_help.html>`_ for more
             details). Required if spatial is ``'Cone'`` or ``'Box'``. Optional
             if spatial is ``'Polygon'``.
         catalog : str
-            The catalog to be used (see the *Notes* section below).
+            The catalog to be used. To list the available catalogs, use
+            :meth:`~astroquery.irsa.IrsaClass.print_catalogs`.
         spatial : str
             Type of spatial query: ``'Cone'``, ``'Box'``, ``'Polygon'``, and
             ``'All-Sky'``. If missing then defaults to ``'Cone'``.
@@ -184,11 +185,12 @@ class IrsaClass(BaseQuery):
             performing a cone or box search. The string can give coordinates
             in various coordinate systems, or the name of a source that will
             be resolved on the server (see `here
-            <http://irsa.ipac.caltech.edu/search_help.html>`_ for more
+            <https://irsa.ipac.caltech.edu/search_help.html>`_ for more
             details). Required if spatial is ``'Cone'`` or ``'Box'``. Optional
             if spatial is ``'Polygon'``.
         catalog : str
-            The catalog to be used (see the *Notes* section below).
+            The catalog to be used. To list the available catalogs, use
+            :meth:`~astroquery.irsa.IrsaClass.print_catalogs`.
         spatial : str
             Type of spatial query: ``'Cone'``, ``'Box'``, ``'Polygon'``, and
             ``'All-Sky'``. If missing then defaults to ``'Cone'``.
@@ -225,8 +227,8 @@ class IrsaClass(BaseQuery):
 
         if get_query_payload:
             return request_payload
-        response = commons.send_request(Irsa.IRSA_URL, request_payload,
-                                        Irsa.TIMEOUT, request_type='GET')
+        response = self._request("GET", url=Irsa.IRSA_URL,
+                                 params=request_payload, timeout=Irsa.TIMEOUT)
         return response
 
     def _parse_spatial(self, spatial, coordinates, radius=None, width=None,
@@ -244,18 +246,18 @@ class IrsaClass(BaseQuery):
             performing a cone or box search. The string can give coordinates
             in various coordinate systems, or the name of a source that will
             be resolved on the server (see `here
-            <http://irsa.ipac.caltech.edu/search_help.html>`_ for more
+            <https://irsa.ipac.caltech.edu/search_help.html>`_ for more
             details). Required if spatial is ``'Cone'`` or ``'Box'``. Optional
             if spatial is ``'Polygon'``.
         radius : str or `~astropy.units.Quantity` object, [optional for spatial is ``'Cone'``]
             The string must be parsable by `~astropy.coordinates.Angle`. The
             appropriate `~astropy.units.Quantity` object from `astropy.units`
             may also be used. Defaults to 10 arcsec.
-      width : str, `~astropy.units.Quantity` object [Required for spatial is ``'Polygon'``.]
+        width : str, `~astropy.units.Quantity` object [Required for spatial is ``'Polygon'``.]
             The string must be parsable by `~astropy.coordinates.Angle`. The
             appropriate `~astropy.units.Quantity` object from `astropy.units`
             may also be used.
-      polygon : list, [Required for spatial is ``'Polygon'``]
+        polygon : list, [Required for spatial is ``'Polygon'``]
             A list of ``(ra, dec)`` pairs as tuples of
             `astropy.coordinates.Angle`s outlining the polygon to search in.
             It can also be a list of `astropy.coordinates` object or strings
@@ -386,8 +388,9 @@ class IrsaClass(BaseQuery):
             name to be used in query functions, and the value is the verbose
             description of the catalog.
         """
-        response = commons.send_request(Irsa.GATOR_LIST_URL, dict(mode='xml'),
-                                        Irsa.TIMEOUT, request_type="GET")
+        response = self._request("GET", url=Irsa.GATOR_LIST_URL,
+                                 params=dict(mode='xml'), timeout=Irsa.TIMEOUT)
+
         root = tree.fromstring(response.content)
         catalogs = {}
         for catalog in root.findall('catalog'):
@@ -404,6 +407,7 @@ class IrsaClass(BaseQuery):
         for catname in catalogs:
             print("{:30s}  {:s}".format(catname, catalogs[catname]))
 
+
 Irsa = IrsaClass()
 
 
@@ -467,7 +471,7 @@ def _parse_dimension(dim):
     # otherwise must be an Angle or be specified in hours...
     else:
         try:
-            new_dim = commons.parse_radius(dim)
+            new_dim = coord.Angle(dim)
             dim = u.Quantity(new_dim.degree, u.Unit('degree'))
         except (u.UnitsError, coord.errors.UnitsError, AttributeError):
             raise u.UnitsError("Dimension not in proper units")
