@@ -5,7 +5,7 @@ import re
 import requests
 import numpy as np
 
-from astropy.tests.helper import pytest
+import pytest
 from astropy.table import Table
 import astropy.coordinates as coord
 import astropy.units as u
@@ -31,12 +31,15 @@ def data_path(filename):
 
 @pytest.fixture
 def patch_get(request):
-    mp = request.getfuncargvalue("monkeypatch")
-    mp.setattr(requests, 'get', get_mockreturn)
+    try:
+        mp = request.getfixturevalue("monkeypatch")
+    except AttributeError:  # pytest < 3
+        mp = request.getfuncargvalue("monkeypatch")
+    mp.setattr(irsa.Irsa, '_request', get_mockreturn)
     return mp
 
 
-def get_mockreturn(url, params=None, timeout=10, **kwargs):
+def get_mockreturn(method, url, params=None, timeout=10, **kwargs):
     filename = data_path(DATA_FILES[params['spatial']])
     content = open(filename, 'rb').read()
     return MockResponse(content, **kwargs)
@@ -117,6 +120,7 @@ def test_query_region_box(coordinates, patch_get):
 
     assert isinstance(result, Table)
 
+
 poly1 = [coord.SkyCoord(ra=10.1, dec=10.1, unit=(u.deg, u.deg)),
          coord.SkyCoord(ra=10.0, dec=10.1, unit=(u.deg, u.deg)),
          coord.SkyCoord(ra=10.0, dec=10.0, unit=(u.deg, u.deg))]
