@@ -2,7 +2,7 @@
 import os
 import types
 import astropy.units as u
-from astropy.tests.helper import pytest
+import pytest
 from astropy import coordinates
 from ... import irsa_dust
 from ...irsa_dust.core import IrsaDust, IrsaDustClass
@@ -48,18 +48,21 @@ def format(coord):
 
 @pytest.fixture
 def patch_request(request):
-    mp = request.getfuncargvalue("monkeypatch")
-    mp.setattr(
-        commons,
-        'send_request',
-        TestDust(
-        ).send_request_mockreturn)
+    try:
+        mp = request.getfixturevalue("monkeypatch")
+    except AttributeError:  # pytest < 3
+        mp = request.getfuncargvalue("monkeypatch")
+    mp.setattr(irsa_dust.IrsaDustClass, '_request',
+               TestDust().send_request_mockreturn)
     return mp
 
 
 @pytest.fixture
 def patch_fromname(request):
-    mp = request.getfuncargvalue("monkeypatch")
+    try:
+        mp = request.getfixturevalue("monkeypatch")
+    except AttributeError:  # pytest < 3
+        mp = request.getfuncargvalue("monkeypatch")
 
     def fromname(self, name):
         if isinstance(name, str):
@@ -325,7 +328,7 @@ class TestDust(DustTestCase):
         types = IrsaDust().list_image_types()
         assert types is not None
 
-    def send_request_mockreturn(self, url, data, timeout):
+    def send_request_mockreturn(self, method, url, data, timeout):
         class MockResponse:
             text = open(self.data(M31_XML), "r").read()
         return MockResponse
