@@ -1,10 +1,14 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
+import imp
 import os
-from astropy.tests.helper import pytest, remote_data
+import astropy.units as u
+import pytest
+import requests
+
+from astropy.tests.helper import remote_data
 from astropy.table import Table
 from ... import irsa_dust
-import requests
-import imp
+
 imp.reload(requests)
 
 M31_XML = "dustm31.xml"
@@ -44,7 +48,7 @@ class TestDust(DustTestCase):
 
     def test_xml_ok(self):
         response = requests.get(
-            irsa_dust.core.IrsaDust.DUST_SERVICE_URL + 
+            irsa_dust.core.IrsaDust.DUST_SERVICE_URL +
             "?locstr=m31")
         data = response.text
         xml_tree = irsa_dust.utils.xml(data)
@@ -52,11 +56,11 @@ class TestDust(DustTestCase):
 
     def test_xml_err(self):
         response = requests.get(
-            irsa_dust.core.IrsaDust.DUST_SERVICE_URL + 
+            irsa_dust.core.IrsaDust.DUST_SERVICE_URL +
             "?locstr=100")
         data = response.text
-        with pytest.raises(Exception) as ex:
-            xml_tree = irsa_dust.utils.xml(data)
+        with pytest.raises(Exception):
+            irsa_dust.utils.xml(data)
 
     @pytest.mark.parametrize(('image_type', 'expected_tails'),
                              [(None, M31_URL_ALL),
@@ -66,7 +70,7 @@ class TestDust(DustTestCase):
                               ])
     def test_extract_image_urls_instance(self, image_type, expected_tails):
         response = requests.get(
-            irsa_dust.core.IrsaDust.DUST_SERVICE_URL + 
+            irsa_dust.core.IrsaDust.DUST_SERVICE_URL +
             "?locstr=m31")
         data = response.text
         url_list = irsa_dust.core.IrsaDust().extract_image_urls(
@@ -82,7 +86,7 @@ class TestDust(DustTestCase):
                               ])
     def test_extract_image_urls_class(self, image_type, expected_tails):
         response = requests.get(
-            irsa_dust.core.IrsaDust.DUST_SERVICE_URL + 
+            irsa_dust.core.IrsaDust.DUST_SERVICE_URL +
             "?locstr=m31")
         data = response.text
         url_list = irsa_dust.core.IrsaDust.extract_image_urls(
@@ -128,11 +132,15 @@ class TestDust(DustTestCase):
         table = irsa_dust.core.IrsaDust.get_extinction_table("m51")
         expected_table = Table.read(self.data(M51_EXT_TBL), format='ipac')
         assert table.meta == expected_table.meta
+        assert table['LamEff'].unit == u.micron
+        assert table['A_SandF'].unit == table['A_SFD'].unit == u.mag
 
     def test_get_extinction_table_instance(self):
         table = irsa_dust.core.IrsaDust().get_extinction_table("m51")
         expected_table = Table.read(self.data(M51_EXT_TBL), format='ipac')
         assert table.meta == expected_table.meta
+        assert table['LamEff'].unit == u.micron
+        assert table['A_SandF'].unit == table['A_SFD'].unit == u.mag
 
     @pytest.mark.parametrize(('image_type', 'expected_tails'),
                              [(None, M31_URL_ALL),
@@ -165,8 +173,9 @@ class TestDust(DustTestCase):
                               ('temperature'),
                               ])
     def test_get_images_async_class(self, image_type):
-        readable_objs = irsa_dust.core.IrsaDust.get_images_async("m81",
-                                                                 image_type=image_type)
+        readable_objs = irsa_dust.core.IrsaDust.get_images_async(
+            "m81", image_type=image_type)
+
         assert readable_objs is not None
 
     @pytest.mark.parametrize(('image_type'),
@@ -176,8 +185,8 @@ class TestDust(DustTestCase):
                               ('temperature'),
                               ])
     def test_get_images_async_instance(self, image_type):
-        readable_objs = irsa_dust.core.IrsaDust().get_images_async("m81",
-                                                                   image_type=image_type)
+        readable_objs = irsa_dust.core.IrsaDust().get_images_async(
+            "m81", image_type=image_type)
         assert readable_objs is not None
 
     def test_get_images_class(self):
