@@ -96,8 +96,9 @@ class NedClass(BaseQuery):
         request_payload['objname'] = object_name
         if get_query_payload:
             return request_payload
-        response = commons.send_request(Ned.OBJ_SEARCH_URL, request_payload,
-                                        Ned.TIMEOUT, request_type='GET')
+        response = self._request("GET", url=Ned.OBJ_SEARCH_URL,
+                                 params=request_payload, timeout=Ned.TIMEOUT)
+
         return response
 
     def query_region(self, coordinates, radius=1 * u.arcmin, equinox='J2000.0',
@@ -180,7 +181,7 @@ class NedClass(BaseQuery):
         if not commons._is_coordinate(coordinates):
             request_payload['objname'] = coordinates
             request_payload['search_type'] = 'Near Name Search'
-            request_payload['radius'] = _parse_radius(radius)
+            request_payload['radius'] = coord.Angle(radius).arcmin
         else:
             try:
                 c = commons.parse_coordinates(coordinates)
@@ -196,13 +197,13 @@ class NedClass(BaseQuery):
                     request_payload['lat'] = dec
                 request_payload['search_type'] = 'Near Position Search'
                 request_payload['in_equinox'] = equinox
-                request_payload['radius'] = _parse_radius(radius)
+                request_payload['radius'] = coord.Angle(radius).arcmin
             except (u.UnitsError, TypeError):
                 raise TypeError("Coordinates not specified correctly")
         if get_query_payload:
             return request_payload
-        response = commons.send_request(Ned.OBJ_SEARCH_URL, request_payload,
-                                        Ned.TIMEOUT, request_type='GET')
+        response = self._request("GET", url=Ned.OBJ_SEARCH_URL,
+                                 params=request_payload, timeout=Ned.TIMEOUT)
         return response
 
     def query_region_iau(self, iau_name, frame='Equatorial', equinox='B1950.0',
@@ -280,8 +281,8 @@ class NedClass(BaseQuery):
         request_payload['in_equinox'] = equinox
         if get_query_payload:
             return request_payload
-        response = commons.send_request(Ned.OBJ_SEARCH_URL, request_payload,
-                                        Ned.TIMEOUT, request_type='GET')
+        response = self._request("GET", url=Ned.OBJ_SEARCH_URL,
+                                 params=request_payload, timeout=Ned.TIMEOUT)
         return response
 
     def query_refcode(self, refcode, get_query_payload=False, verbose=False):
@@ -339,8 +340,8 @@ class NedClass(BaseQuery):
         request_payload['refcode'] = refcode
         if get_query_payload:
             return request_payload
-        response = commons.send_request(Ned.OBJ_SEARCH_URL, request_payload,
-                                        Ned.TIMEOUT, request_type='GET')
+        response = self._request("GET", url=Ned.OBJ_SEARCH_URL,
+                                 params=request_payload, timeout=Ned.TIMEOUT)
         return response
 
     def get_images(self, object_name, get_query_payload=False,
@@ -480,8 +481,8 @@ class NedClass(BaseQuery):
         if get_query_payload:
             return request_payload
         url = Ned.SPECTRA_URL if item == 'spectra' else Ned.IMG_DATA_URL
-        response = commons.send_request(url, request_payload,
-                                        Ned.TIMEOUT, request_type='GET')
+        response = self._request("GET", url=url, params=request_payload,
+                                 timeout=Ned.TIMEOUT)
         return self.extract_image_urls(response.text)
 
     def extract_image_urls(self, html_in):
@@ -497,7 +498,7 @@ class NedClass(BaseQuery):
         """
         base_url = 'http://ned.ipac.caltech.edu'
         pattern = re.compile(
-            '<a\s+href\s*?="?\s*?(.+?fits.gz)"?\s*?>\s*?(?:Retrieve|FITS)</a>',
+            r'<a\s+href\s*?="?\s*?(.+?fits.gz)"?\s*?>\s*?(?:Retrieve|FITS)</a>',
             re.IGNORECASE)
         matched_urls = pattern.findall(html_in)
         url_list = [base_url + img_url for img_url in matched_urls]
@@ -607,8 +608,8 @@ class NedClass(BaseQuery):
                                                      datetime.now().year)
         if get_query_payload:
             return request_payload
-        response = commons.send_request(Ned.DATA_SEARCH_URL, request_payload,
-                                        Ned.TIMEOUT, request_type='GET')
+        response = self._request("GET", url=Ned.DATA_SEARCH_URL,
+                                 params=request_payload, timeout=Ned.TIMEOUT)
         return response
 
     def _request_payload_init(self):
@@ -700,26 +701,10 @@ class NedClass(BaseQuery):
                     "found in self.response, and the error in "
                     "self.table_parse_error.")
 
+
 Ned = NedClass()
 
 
-def _parse_radius(radius):
-    """
-    Parses the radius and returns it in the format expected by NED.
-
-    Parameters
-    ----------
-    radius : str, `~astropy.units.Quantity`
-
-    Returns
-    -------
-    radius_in_min : float
-        The value of the radius in arcminutes.
-
-    """
-    return coord.Angle(radius).to('arcmin').value
-
-
 def _check_ned_valid(string):
     """
     Checks if the VOTable returned has an error parameter
