@@ -53,11 +53,12 @@ class AstroQuery(object):
         else:
             self._timeout = value
 
-    def request(self, session, cache_location=None, stream=False, auth=None):
+    def request(self, session, cache_location=None, stream=False,
+                auth=None, verify=True):
         return session.request(self.method, self.url, params=self.params,
                                data=self.data, headers=self.headers,
                                files=self.files, timeout=self.timeout,
-                               stream=stream, auth=auth)
+                               stream=stream, auth=auth, verify=verify)
 
     def hash(self):
         if self._hash is None:
@@ -66,10 +67,10 @@ class AstroQuery(object):
                 if isinstance(k, dict):
                     entry = (tuple(sorted(k.items(),
                                           key=_replace_none_iterable)))
-                    entry = tuple((k_,v_.read()) if hasattr(v_,'read')
-                                  else (k_,v_) for k_,v_ in entry)
-                    for k_,v_ in entry:
-                        if hasattr(v_,'read') and hasattr(v_,'seek'):
+                    entry = tuple((k_, v_.read()) if hasattr(v_, 'read')
+                                  else (k_, v_) for k_, v_ in entry)
+                    for k_, v_ in entry:
+                        if hasattr(v_, 'read') and hasattr(v_, 'seek'):
                             v_.seek(0)
 
                     request_key += entry
@@ -81,7 +82,8 @@ class AstroQuery(object):
                 elif isinstance(k, six.string_types):
                     request_key += (k,)
                 else:
-                    raise TypeError("{0} must be a dict, tuple, str, or list")
+                    raise TypeError("{0} must be a dict, tuple, str, or "
+                                    "list".format(k))
             self._hash = hashlib.sha224(pickle.dumps(request_key)).hexdigest()
         return self._hash
 
@@ -96,7 +98,7 @@ class AstroQuery(object):
                 response = pickle.load(f)
             if not isinstance(response, requests.Response):
                 response = None
-        except:
+        except IOError:  # TODO: change to FileNotFoundError once drop py2 support
             response = None
         if response:
             log.debug("Retrieving data from {0}".format(request_file))
@@ -130,7 +132,7 @@ class BaseQuery(object):
 
     def _request(self, method, url, params=None, data=None, headers=None,
                  files=None, save=False, savedir='', timeout=None, cache=True,
-                 stream=False, auth=None):
+                 stream=False, auth=None, continuation=True, verify=True):
         """
         A generic HTTP request method, similar to `requests.Session.request`
         but with added caching-related tools
@@ -141,7 +143,8 @@ class BaseQuery(object):
 
         Parameters
         ----------
-        method : 'GET' or 'POST'
+        method : str
+            'GET' or 'POST'
         url : str
         params : None or dict
         data : None or dict
@@ -156,6 +159,11 @@ class BaseQuery(object):
         savedir : str
             The location to save the local file if you want to save it
             somewhere other than `BaseQuery.cache_location`
+        timeout : int
+        cache : bool
+        verify : bool
+        continuation : bool
+        stream : bool
 
         Returns
         -------
@@ -176,7 +184,8 @@ class BaseQuery(object):
             # REDUNDANT: spinner has this log.info("Downloading
             # {0}...".format(local_filename))
             self._download_file(url, local_filepath, timeout=timeout,
-                                auth=auth, cache=cache)
+                                auth=auth, cache=cache,
+                                continuation=continuation)
             return local_filepath
         else:
             query = AstroQuery(method, url, params=params, data=data,
@@ -185,33 +194,62 @@ class BaseQuery(object):
                     (not cache)):
                 with suspend_cache(self):
                     response = query.request(self._session, stream=stream,
-                                             auth=auth)
+                                             auth=auth, verify=verify)
             else:
                 response = query.from_cache(self.cache_location)
                 if not response:
                     response = query.request(self._session,
                                              self.cache_location,
                                              stream=stream,
-                                             auth=auth)
+                                             auth=auth,
+                                             verify=verify)
                     to_cache(response, query.request_file(self.cache_location))
             self._last_query = query
             return response
 
     def _download_file(self, url, local_filepath, timeout=None, auth=None,
-                       cache=False):
+                       continuation=True, cache=False, **kwargs):
         """
         Download a file.  Resembles `astropy.utils.data.download_file` but uses
         the local ``_session``
         """
         response = self._session.get(url, timeout=timeout, stream=True,
-                                     auth=auth)
+                                     auth=auth, **kwargs)
         response.raise_for_status()
         if 'content-length' in response.headers:
             length = int(response.headers['content-length'])
         else:
             length = None
 
-        if cache and os.path.exists(local_filepath):
+        if ((os.path.exists(local_filepath) and ('Accept-Ranges' in
+                                                 response.headers) and
+             continuation)):
+            open_mode = 'ab'
+
+            existing_file_length = os.stat(local_filepath).st_size
+            if length is not None and existing_file_length >= length:
+                # all done!
+                log.info("Found cached file {0} with expected size {1}."
+                         .format(local_filepath, existing_file_length))
+                return
+            elif existing_file_length == 0:
+                open_mode = 'wb'
+            else:
+                log.info("Continuing download of file {0}, with {1} bytes to "
+                         "go ({2}%)".format(local_filepath,
+                                            length - existing_file_length,
+                                            (length-existing_file_length)/length*100))
+
+                # bytes are indexed from 0:
+                # https://en.wikipedia.org/wiki/List_of_HTTP_header_fields#range-request-header
+                end = "{0}".format(length-1) if length is not None else ""
+                self._session.headers['Range'] = "bytes={0}-{1}".format(existing_file_length,
+                                                                        end)
+
+                response = self._session.get(url, timeout=timeout, stream=True,
+                                             auth=auth, **kwargs)
+
+        elif cache and os.path.exists(local_filepath):
             if length is not None:
                 statinfo = os.stat(local_filepath)
                 if statinfo.st_size != length:
@@ -220,6 +258,7 @@ class BaseQuery(object):
                                 .format(local_filepath,
                                         statinfo.st_size,
                                         length))
+                    open_mode = 'wb'
                 else:
                     log.info("Found cached file {0} with expected size {1}."
                              .format(local_filepath, statinfo.st_size))
@@ -229,6 +268,8 @@ class BaseQuery(object):
                 log.info("Found cached file {0}.".format(local_filepath))
                 response.close()
                 return
+        else:
+            open_mode = 'wb'
 
         blocksize = astropy.utils.data.conf.download_block_size
 
@@ -237,7 +278,7 @@ class BaseQuery(object):
         with ProgressBarOrSpinner(
             length, ('Downloading URL {0} to {1} ...'
                      .format(url, local_filepath))) as pb:
-            with open(local_filepath, 'wb') as f:
+            with open(local_filepath, open_mode) as f:
                 for block in response.iter_content(blocksize):
                     f.write(block)
                     bytes_read += blocksize
