@@ -5,8 +5,8 @@ SIMBAD Query Tool
 
 The SIMBAD query tool creates a `script query
 <http://simbad.u-strasbg.fr/simbad/sim-fscript>`__ that returns VOtable XML
-data that is then parsed into a SimbadResult object.
-This object then parses the data and returns a table parsed with `astropy.io.votable.parse`.
+data that is then parsed into a SimbadResult object.  This object then
+parses the data and returns a table parsed with `astropy.io.votable.parse`.
 """
 from astropy import config as _config
 
@@ -17,17 +17,17 @@ class Conf(_config.ConfigNamespace):
     """
     server = _config.ConfigItem(
         ['simbad.u-strasbg.fr', 'simbad.harvard.edu'],
-        'Name of the SIMBAD mirror to use.'
-        )
+        'Name of the SIMBAD mirror to use.')
+
     timeout = _config.ConfigItem(
         60,
-        'Time limit for connecting to Simbad server.'
-        )
+        'Time limit for connecting to Simbad server.')
+
     row_limit = _config.ConfigItem(
         # O defaults to the maximum limit
         0,
-        'Maximum number of rows that will be fetched from the result.'
-        )
+        'Maximum number of rows that will be fetched from the result.')
+
 
 conf = Conf()
 
