@@ -1,5 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from astropy.tests.helper import remote_data, pytest
+import pytest
+
+from astropy.tests.helper import remote_data
 from astropy.io.fits import HDUList
 
 from ...skyview import SkyView
@@ -12,7 +14,7 @@ def test_get_image_list():
                                     survey=['Fermi 5', 'HRI', 'DSS'])
     assert len(urls) == 3
     for url in urls:
-        assert url.startswith('http://skyview.gsfc.nasa.gov/tempspace/fits/')
+        assert url.startswith('https://skyview.gsfc.nasa.gov/tempspace/fits/')
 
 
 @remote_data
@@ -39,9 +41,9 @@ class TestSkyviewRemote(object):
         # The print should help discover changes
         print("Survey: {0} \n Canned reference return: {1} \n"
               "Online service return: {2}".format(
-                survey, survey_data,
-                self.SkyView.survey_dict.get(
-                    survey, "{0} is not in online version".format(survey))))
+                  survey, survey_data,
+                  self.SkyView.survey_dict.get(
+                      survey, "{0} is not in online version".format(survey))))
 
         assert set(self.SkyView.survey_dict[survey]) == set(survey_data)
 
