@@ -21,7 +21,7 @@ class Conf(_config.ConfigNamespace):
         'Splatalogue SLAP interface URL (not used).')
     query_url = _config.ConfigItem(
         'http://www.cv.nrao.edu/php/splat/c_export.php',
-        'SSplatalogue web interface URL.')
+        'Splatalogue web interface URL.')
     timeout = _config.ConfigItem(
         60,
         'Time limit for connecting to Splatalogue server.')
@@ -29,6 +29,7 @@ class Conf(_config.ConfigNamespace):
         1000,
         'Limit to number of lines exported.')
 
+
 conf = Conf()
 
 from . import load_species_table
