@@ -84,6 +84,7 @@ class UkidssClass(QueryWithLogin):
 
     def __init__(self, username=None, password=None, community=None,
                  database='UKIDSSDR7PLUS', programme_id='all'):
+        super(UkidssClass, self).__init__()
         self.database = database
         self.programme_id = programme_id  # 102 = GPS
         self.session = None
@@ -360,7 +361,7 @@ class UkidssClass(QueryWithLogin):
             query_url = self.ARCHIVE_URL
             ra = request_payload.pop('ra')
             dec = request_payload.pop('dec')
-            radius = commons.parse_radius(radius).degree
+            radius = coord.Angle(radius).degree
             del request_payload['sys']
             request_payload['userSelect'] = 'default'
             request_payload['minRA'] = str(
@@ -416,7 +417,7 @@ class UkidssClass(QueryWithLogin):
             The list of URLS extracted from the input.
         """
         # Parse html input for links
-        ahref = re.compile('href="([a-zA-Z0-9_\.&\?=%/:-]+)"')
+        ahref = re.compile(r'href="([a-zA-Z0-9_\.&\?=%/:-]+)"')
         links = ahref.findall(html_in)
         return links
 
@@ -611,7 +612,8 @@ class UkidssClass(QueryWithLogin):
                 'http://surveys.roe.ac.uk:8080/wsa/getImage_form.jsp')
         else:
             response = requests.get(
-                'http://surveys.roe.ac.uk:8080/wsa/getImage_form.jsp')
+                url='http://surveys.roe.ac.uk:8080/wsa/getImage_form.jsp')
+
         root = BeautifulSoup(response.content)
         databases = [x.attrs['value'] for x in
                      root.find('select').findAll('option')]
@@ -645,8 +647,8 @@ class UkidssClass(QueryWithLogin):
             response = self.session.get(url, params=request_payload,
                                         timeout=self.TIMEOUT)
         else:
-            response = commons.send_request(url, request_payload, self.TIMEOUT,
-                                            request_type='GET')
+            response = self._request("GET", url=url, params=request_payload,
+                                     timeout=self.TIMEOUT)
         return response
 
     def _check_page(self, url, keyword, wait_time=1, max_attempts=30):
@@ -655,7 +657,7 @@ class UkidssClass(QueryWithLogin):
             if self.logged_in():
                 response = self.session.get(url)
             else:
-                response = requests.get(url)
+                response = requests.get(url=url)
             self.response = response
             content = response.text
             if re.search("error", content, re.IGNORECASE):
@@ -671,6 +673,7 @@ class UkidssClass(QueryWithLogin):
             raise TimeoutError("Page did not load.")
         return response
 
+
 Ukidss = UkidssClass()
 
 
@@ -767,7 +770,7 @@ def _parse_dimension(dim):
     # otherwise must be an Angle or be specified in hours...
     else:
         try:
-            new_dim = commons.parse_radius(dim).degree
+            new_dim = coord.Angle(dim).degree
             dim_in_min = u.Quantity(
                 value=new_dim, unit=u.deg).to(u.arcmin).value
         except (u.UnitsError, coord.errors.UnitsError, AttributeError):
