@@ -10,4 +10,4 @@ from .download_file_list import *
 from .class_or_instance import *
 from .commons import *
 from .process_asyncs import async_to_sync
-from .docstr_chompers import prepend_docstr_noreturns
+from .docstr_chompers import prepend_docstr_nosections
