@@ -2,7 +2,7 @@
 import os
 import requests
 from numpy import testing as npt
-from astropy.tests.helper import pytest
+import pytest
 from astropy.table import Table
 import astropy.units as u
 from astropy.extern import six
@@ -27,7 +27,10 @@ def data_path(filename):
 
 @pytest.fixture
 def patch_post(request):
-    mp = request.getfuncargvalue("monkeypatch")
+    try:
+        mp = request.getfixturevalue("monkeypatch")
+    except AttributeError:  # pytest < 3
+        mp = request.getfuncargvalue("monkeypatch")
     mp.setattr(requests.Session, 'request', post_mockreturn)
     return mp
 
@@ -50,7 +53,10 @@ def parse_objname(obj):
 
 @pytest.fixture
 def patch_coords(request):
-    mp = request.getfuncargvalue("monkeypatch")
+    try:
+        mp = request.getfixturevalue("monkeypatch")
+    except AttributeError:  # pytest < 3
+        mp = request.getfuncargvalue("monkeypatch")
     mp.setattr(commons, 'parse_coordinates', parse_objname)
     return mp
 
