@@ -2,7 +2,7 @@
 import os.path
 
 import requests
-from astropy.tests.helper import pytest
+import pytest
 from astropy.io import ascii
 from astropy.table import Table
 from astropy.units import arcsec
@@ -32,7 +32,10 @@ class MockResponseXmatch(MockResponse):
 
 @pytest.fixture
 def patch_request(request):
-    mp = request.getfuncargvalue("monkeypatch")
+    try:
+        mp = request.getfixturevalue("monkeypatch")
+    except AttributeError:  # pytest < 3
+        mp = request.getfuncargvalue("monkeypatch")
     mp.setattr(requests, "_request", request_mockreturn)
     return mp
 
@@ -72,6 +75,7 @@ def test_xmatch_is_avail_table(monkeypatch):
     assert xm.is_table_available('vizier:II/311/wise')
     assert not xm.is_table_available('blablabla')
 
+
 def test_xmatch_query_local(monkeypatch):
     xm = XMatch()
     monkeypatch.setattr(xm, '_request', request_mockreturn)
